@@ -26,8 +26,12 @@ import seaborn as sns
 import scipy as sp
 from scipy import signal
 
-os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = '1'
-import pygame
+try:
+    import pygame
+
+    os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = '1'
+except ImportError:
+    logging.warn('Try pip install pygame')
 
 try:
     import ctypes
@@ -64,8 +68,10 @@ except ImportError:
     logging.warn('Try pip install pyuserinput and also have pyHook installed on your computer from below website:\n'
                  'http://www.lfd.uci.edu/~gohlke/pythonlibs')
 
-
-# matplotlib.use('TkAgg')  # for mac
+try:
+    matplotlib.use('QT5Agg')  # for mac, TkAgg
+except:
+    logging.warn('backend qt5 not supported')
 
 
 # Wayne:
@@ -350,6 +356,17 @@ def list_all_files(root: str, keys=[], outliers=[], full_path=False):
     return _files
 
 
+def count_file_lines(file):
+    def block(f_: 'File', size_=65536):
+        while True:
+            b = f_.read(size_)
+            if not b: break
+            yield b
+
+    with open(file, 'r', encoding='utf-8', errors='ignore') as f:
+        return sum(bl.count('\n') for bl in block(f))
+
+
 class GlobalHotKeys:
     """
     Register a key using the register() method, or using the @register decorator
@@ -693,7 +710,7 @@ def peak_det(v, delta, x=None):
     return np.array(maxtab), np.array(mintab)
 
 
-def butter_bandpass_filter(x, order=2, wn=0.2, btype='low'):
+def butter_bandpass_filter(x, order=2, wn=0.2, btype='lowpass'):
     """
     ButterWorth 滤波器
 
